# PulpContainerClient::ContentSignaturesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](ContentSignaturesApi.md#list) | **GET** /pulp/api/v3/content/container/signatures/ | List manifest signatures
[**read**](ContentSignaturesApi.md#read) | **GET** {container_manifest_signature_href} | Inspect a manifest signature



## list

> PaginatedcontainerManifestSignatureResponseList list(opts)

List manifest signatures

ViewSet for image signatures.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::ContentSignaturesApi.new
opts = {
  digest: 'digest_example', # String | Filter results where digest matches value
  digest__in: ['digest__in_example'], # Array<String> | Filter results where digest is in a comma-separated list of values
  key_id: 'key_id_example', # String | Filter results where key_id matches value
  key_id__in: ['key_id__in_example'], # Array<String> | Filter results where key_id is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  manifest: ['manifest_example'], # Array<String> | Multiple values may be separated by commas.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List manifest signatures
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling ContentSignaturesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **digest** | **String**| Filter results where digest matches value | [optional] 
 **digest__in** | [**Array&lt;String&gt;**](String.md)| Filter results where digest is in a comma-separated list of values | [optional] 
 **key_id** | **String**| Filter results where key_id matches value | [optional] 
 **key_id__in** | [**Array&lt;String&gt;**](String.md)| Filter results where key_id is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **manifest** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerManifestSignatureResponseList**](PaginatedcontainerManifestSignatureResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> ContainerManifestSignatureResponse read(container_manifest_signature_href, opts)

Inspect a manifest signature

ViewSet for image signatures.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::ContentSignaturesApi.new
container_manifest_signature_href = 'container_manifest_signature_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a manifest signature
  result = api_instance.read(container_manifest_signature_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling ContentSignaturesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_manifest_signature_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerManifestSignatureResponse**](ContainerManifestSignatureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

